@@ -1,35 +1,102 @@
 package MIDI::Simple::Drummer;
-our $VERSION = '0.00_23';
+our $VERSION = '0.02_1';
 use strict;
 use warnings;
 use MIDI::Simple;
 
+BEGIN {
+    require constant;
+
+    # Declare duration identifiers.
+    my @notes = qw(w h q e s y x);
+    # Add the duration identifiers to MIDI::Simple.
+    %MIDI::Simple::Length = _set_durations(@notes);
+
+    # Create constants with maningful duration names.
+    my %by_name;
+    @by_name{@notes} = qw(whole half quarter eighth sixteenth thirtysecond sixtyfourth);
+    my %by_number;
+    @by_number{@notes} = qw(1st 2nd 4th 8th 16th 32nd 64th);
+
+    # Process each duration.
+    for my $n (keys %MIDI::Simple::Length) {
+        # Get the duration part of the note name.
+        my $name = $n =~ /([whqesyx])n$/o ? $1 : '';
+        if ($name) {
+            # Create the meaningful prefix for the named constant.
+            my $prefix = '';
+            $prefix .= 'triplet'       if $n =~ /t\w/o;
+            $prefix .= 'double_dotted' if $n =~ /^dd/o;
+            $prefix .= 'dotted'        if $n =~ /^d[^d]/o;
+            $prefix .= '_' if $prefix;
+
+            # Add the constant accessed as $d->DOTTED_SIXTYFOURTH or $d->TRIPLET_8TH
+            constant->import(uc($prefix . $by_name{$name}) => $n); # LeoNerd++
+            $prefix .= '_' unless $prefix;
+            constant->import(uc($prefix . $by_number{$name}) => $n);
+        }
+        else {
+            warn "ERROR: Unknown note value '$n' - Skipping."
+        }
+    }
+
+    sub _set_durations { # Calculate named note durations.
+        my @durations = @_;
+
+        # Decalare a hash of duration values to return.
+        my %duration = ();
+
+        # Set the initial duratoin.
+        my $last = 'w';
+
+        for my $d (@durations) {
+            # Create a MIDI::Simple note identifier.
+            my $n = $d . 'n';
+
+            # Compute the durations for each note.
+            $duration{$n} = $d eq $last ? 4 : $duration{$last . 'n'} / 2;
+            $duration{'d'.$n} = $duration{$n} + $duration{$n} / 2;
+            $duration{'dd'.$n} = $duration{'d'.$n} + $duration{$n} / 4;
+            $duration{'t'.$n} = $duration{$n} / 3 * 2;
+
+            # Increment the last seen duration.
+            $last = $d;
+        }
+
+        return %duration;
+    }
+}
+
 sub new { # Is there a drummer in the house?
     my $class = shift;
     my $self = {
         # MIDI
-        -channel => 9,
-        -volume => 100,
+        -channel => 9, # Default MIDI-perl drum channel
+        -volume => 100, # 120 max
+        -pan => 64, # L 1 - R 127
         # Rhythm
         -accent => 30, # Volume increment
-        -bpm => 120,
+        -bpm => 120, # 1 qn = .5 seconds = 500,000 microseconds
         -phrases => 4, # Also equals measures
+        -bars => 4,   # Number of measures
         -beats => 4,   # Beats per measure
+        -swing => 0,   # Triplet=1 or Even=0 time TODO Make this a percentage
         # The Goods[TM].
         -score => undef,
-        -file => 'Drummer.mid',
+        -file => 'Drummer.mid', # Default if not provided by the caller.
         -kit => undef,
         -patterns => undef,
-        @_
+        @_ # Capture any additional arguments provided to the constructor.
     };
     bless $self, $class;
     $self->_setup();
     return $self;
 }
+
 sub _setup { # Where's my Roadies, Man?
     my $self = shift;
 
-    # XXX For now there is only one, linear score so: TODO Multitrack!
+    # TODO Multitrack! For now there is only one, linear score.
     $self->{-score} ||= MIDI::Simple->new_score;
     $self->{-score}->noop('c'.$self->{-channel}, 'V'.$self->{-volume});
     $self->{-score}->set_tempo(int(60_000_000 / $self->{-bpm}));
@@ -41,21 +108,23 @@ sub _setup { # Where's my Roadies, Man?
     return $self;
 }
 
-sub _n2p { return \%MIDI::notenum2percussion } # Convenience functions.
+sub _durations { return \%MIDI::Simple::Length } # Convenience functions.
+sub _n2p { return \%MIDI::notenum2percussion }
 sub _p2n { return \%MIDI::percussion2notenum }
 
-sub WHOLE {'wn'} # Readable durations.                                                                                                
-sub HALF {'hn'}
-sub QUARTER {'qn'}
-sub EIGHTH {'en'}
-sub SIXTEENTH {'sn'} # TODO THIRTYSECOND, SIXTYFOURTH
+# Accessors:
 
-# Accessors.
 sub channel { # The general MIDI drumkit is often channel 9.
     my $self = shift;
     $self->{-channel} = shift if @_;
     return $self->{-channel}
 }
+sub pan { # (1) Left - Middle - Right (127)
+    my $self = shift;
+    $self->{-pan} = shift if @_;
+    $self->{-score}->control_change($self->{-channel}, 10, $self->{-pan});
+    return $self->{-pan}
+}
 sub bpm { # Beats per minute.
     my $self = shift;
     $self->{-bpm} = shift if @_;
@@ -71,11 +140,21 @@ sub phrases { # o/` How many more times? Treat me the way you wanna do?
     $self->{-phrases} = shift if @_;
     return $self->{-phrases}
 }
+sub bars { # Number of measures.
+    my $self = shift;
+    $self->{-bars} = shift if @_;
+    return $self->{-bars}
+}
 sub beats { # Beats per measure.
     my $self = shift;
     $self->{-beats} = shift if @_;
     return $self->{-beats}
 }
+sub swing { # Triplet or Even time.
+    my $self = shift;
+    $self->{-swing} = shift if @_;
+    return $self->{-swing}
+}
 sub file { # The name of the "file.mid" output.
     my $self = shift;
     $self->{-file} = shift if @_;
@@ -91,8 +170,7 @@ sub score { # The MIDI::Simple score with no-op-ability.
 }
 
 # API: Subclass and redefine to emit nuance.
-# API: Make a "ducker" method (i.e. the opposite).
-sub accent { # Pump up the [dynamics] (default Volume)!
+sub accent { # Pump up the Volume!
     my $self = shift;
     $self->{-accent} = shift if @_;
     my $accent = $self->{-accent} + $self->volume;
@@ -100,6 +178,14 @@ sub accent { # Pump up the [dynamics] (default Volume)!
         if $accent > $MIDI::Simple::Volume{fff};
     return $accent;
 }
+sub duck { # Drop the volume.
+    my $self = shift;
+    $self->{-accent} = shift if @_;
+    my $duck = $self->volume - $self->{-accent};
+    $duck = $MIDI::Simple::Volume{ppp}
+        if $duck > $MIDI::Simple::Volume{ppp};
+    return $duck;
+}
 
 sub kit { # Arrayrefs of patches.
     my $self = shift;
@@ -110,20 +196,19 @@ sub patterns { # Coderefs of patterns.
     return $self->_type('-patterns', @_);
 }
 
-# XXX This _type() method is exceedingly ugly.
 sub _type { # Both kit and pattern access.
     my $self = shift;
     my $type = shift || return;
     if(!@_) { # If no arguments return all known types.
         return $self->{$type};
     }
-    elsif(@_ == 1) { # Return a named type.
+    elsif(@_ == 1) { # Return a named type with either name=>value or just value.
         my $i = shift;
         return wantarray
             ? ($i => $self->{$type}{$i})
             : $self->{$type}{$i};
     }
-    elsif(@_ > 1 && !(@_ % 2)) { # Add new types.
+    elsif(@_ > 1 && !(@_ % 2)) { # Add new types if given an even list.
         my %args = @_;
         my @t = ();
         while(my($i, $v) = each %args) {
@@ -137,7 +222,7 @@ sub _type { # Both kit and pattern access.
                 ? [map { $self->{$type}{$_} } @t]   # Arrayref of types.
                 : $self->{$type}{$t[0]};            # Else single type.
     }
-    else {
+    else { # Unlikely to ever be triggered.
         warn 'WARNING: Mystery arguments. Giving up.'
     }
 }
@@ -145,7 +230,9 @@ sub _type { # Both kit and pattern access.
 sub name_of { # Return instrument name(s) given kit keys.
     my $self = shift;
     my $key = shift || return;
-    return wantarray ? @{$self->kit($key)} : join ',', @{$self->kit($key)};
+    return wantarray
+        ? @{$self->kit($key)} # List of names
+        : join ',', @{$self->kit($key)}; # CSV of names
 }
 
 sub _set_get { # Internal kit access.
@@ -156,7 +243,7 @@ sub _set_get { # Internal kit access.
     return $self->option_strike(@{$self->kit($key)});
 }
 
-# API: Add "something"s to your kit & patterns, in a subclass.
+# API: Add other keys to your kit & patterns, in a subclass.
 sub backbeat { return shift->_set_get('backbeat', @_) }
 sub snare    { return shift->_set_get('snare', @_) }
 sub kick     { return shift->_set_get('kick', @_) }
@@ -168,26 +255,28 @@ sub tom      { return shift->_set_get('tom', @_) }
 
 sub strike { # Return note values.
     my $self = shift;
-    my @patches = @_ ? @_ : @{$self->kit('snare')};
+    my @patches = @_ ? @_ : @{$self->kit('snare')}; # Default to snare.
+    # Build MIDI::Simple note names from the patch numbers.
     my @notes = map { 'n' . $MIDI::percussion2notenum{$_} } @patches;
     return wantarray ? @notes : join(',', @notes);
 }
-# API: Redefine this method to use a different decision than C<rand>.
 sub option_strike { # When in doubt, crash.
     my $self = shift;
-    my @patches = @_ ? @_ : @{$self->kit('crash')};
+    my @patches = @_ ? @_ : @{$self->kit('crash')}; # Default to the crash patches.
+    # API: Redefine this method to use a different decision than rand().
     return $self->strike($patches[int(rand @patches)]);
 }
 
-sub rotate { # Rotate through a list of patches. Default backbeat.
+sub rotate { # Rotate through a list of patches.
     my $self = shift;
-    my $beat = shift || 1;
-    my $patches = shift || $self->kit('backbeat');
+    my $beat = shift || 1; # Assume that we are on the first beat if none is given.
+    my $patches = shift || $self->kit('backbeat'); # Default backbeat.
     return $self->strike($patches->[$beat % @$patches]);
 }
 sub backbeat_rhythm { # AC/DC forever.
     # Rotate the backbeat with tick & post-fill strike.
     my $self = shift;
+    # Set the default parameters with an argument override.
     my %args = (
         -beat => 1,
         -fill => 0,
@@ -196,7 +285,7 @@ sub backbeat_rhythm { # AC/DC forever.
         -patches => scalar $self->kit('crash'),
         @_
     );
-    # Strike a cymbal (or the provided patches).
+    # Strike a cymbal or use the provided patches.
     my $c = $args{-beat} == 1 && $args{-fill}
         ? $self->option_strike(@{$args{-patches}})
         : $self->strike(@{$args{-tick}});
@@ -210,30 +299,32 @@ sub backbeat_rhythm { # AC/DC forever.
 sub note { return shift->{-score}->n(@_) }
 sub rest { return shift->{-score}->r(@_) }
 
-sub count_in {
+sub count_in { # And-a one, and-a two...
     my $self = shift;
-    my $bars = shift || 1;
+    my $bars = shift || 1; # Assume that we are on the first bar if none is given.
+    # Define the note to strike with the given patch. Default 'tick' patch.
     my $strike = @_ ? $self->strike(@_) : $self->tick;
     for my $i (1 .. $self->beats * $bars) {
+        # Accent if we are on the first beat.
         $self->score('V'.$self->accent) if $i % $self->beats == 1;
-        $self->note(QUARTER(), $strike);
+        $self->note($self->QUARTER(), $strike);
+        # Reset the note volume if we just played the first beat.
         $self->score('V'.$self->volume) if $i % $self->beats == 1;
     }
     return $strike;
 }
-sub metronome {
+sub metronome { # Keep time with a single patch. Default Pedal Hi-Hat.
     my $self = shift;
     return $self->count_in($self->phrases, shift || 'Pedal Hi-Hat');
 }
 
-# XXX This "skipping named types" is a bit dodgy but seems to work.
 sub beat { # Pattern selector method.
     my $self = shift;
     my %args = (
-        -name => 0,
-        -fill => 0,
-        -last => 0,
-        -type => '',
+        -name => 0, # Provide a pattern name
+        -fill => 0, # Provide a fill pattern name
+        -last => 0, # Is this the last beat?
+        -type => '', # Is this a fill if not named in -fill?
         @_
     );
 
@@ -247,7 +338,7 @@ sub beat { # Pattern selector method.
     my $n = $args{-name} && $args{-type} && $args{-name} !~ /^.+\s+$args{-type}$/
           ? "$args{-name} $args{-type}" : $args{-name};
 
-    if(@k == 1) { # Return the only pattern if there is only one.
+    if(@k == 1) { # Return the pattern if there is only one.
         $n = $k[0];
     }
     else { # Otherwise choose a different pattern.
@@ -262,27 +353,33 @@ sub beat { # Pattern selector method.
         }
     }
 
-    # Beat it.
+    # Beat it - i.e. add the pattern to the score.
     $self->{-patterns}{$n}->($self, %args);
+    # Return the beat note.
     return $n;
 }
 sub fill {
     my $self = shift;
+    # Add the beat pattern to the score.
     return $self->beat(@_, -type => 'fill');
 }
 
+sub sync_tracks {
+    my $self = shift;
+    $self->{-score}->synch(@_);
+}
+
 sub write { # You gotta get it out there, you know. Make some buzz, Man.
     my $self = shift;
+    # Write the score to a provided file or the one already defined.
     my $file = shift || $self->{-file};
     $self->{-score}->write_score($file);
+    # Return the filename if it was created or zero if not.
+    # XXX Check file-size not existance.
     return -e $file ? $file : 0;
 }
 
 # API: Redefine these methods in a subclass.
-sub _default_patterns {
-    my $self = shift;
-    return {};  # Nothing to see here. Move along.
-}
 sub _default_kit {
     my $self = shift;
     return {
@@ -312,6 +409,10 @@ sub _default_kit {
       ],
   };
 }
+sub _default_patterns {
+    my $self = shift;
+    return {};
+}
 
 1;
 __END__
@@ -320,22 +421,28 @@ __END__
 
 MIDI::Simple::Drummer - Glorified metronome
 
-=head1 ABSTRACT
-
-Is there a drummer in the house?
-
 =head1 SYNOPSIS
 
   # A glorified metronome:
   use MIDI::Simple::Drummer;
   my $d = MIDI::Simple::Drummer->new(-bpm => 100);
   $d->count_in;
-  for(1 .. $d->phrases * $d->beats) {
+  for(1 .. $d->phrases * $d->bars) {
     $d->note($d->EIGHTH, $d->backbeat_rhythm(-beat => $_));
     $d->note($d->EIGHTH, $d->tick);
   }
 
-  # A smarter drummer:
+  # Shuffle:
+  use MIDI::Simple::Drummer;
+  my $d = MIDI::Simple::Drummer->new(-bpm => 100);
+  $d->count_in;
+  for(1 .. $d->phrases * $d->bars) {
+    $d->note($d->TRIPLET_EIGHTH, $d->backbeat_rhythm(-beat => $_));
+    $d->rest($d->TRIPLET_EIGHTH);
+    $d->note($d->TRIPLET_EIGHTH, $d->tick);
+  }
+
+  # A rock drummer:
   use MIDI::Simple::Drummer::Rock;
   $d = MIDI::Simple::Drummer::Rock->new(-bpm => 100);
   my($beat, $fill) = (0, 0);
@@ -356,24 +463,44 @@ Is there a drummer in the house?
     my $d = shift;
     $d->note($d->EIGHTH, $d->option_strike;
     $d->note($d->EIGHTH, $d->strike('Splash Cymbal','Bass Drum 1'));
-    $d->note($d->SIXTEENTH, $d->snare) for 0 .. 2;
+    $d->note($d->TRIPLET_SIXTEENTH, $d->snare) for 0 .. 2;
     $d->rest($d->SIXTEENTH);
     $d->note($d->EIGHTH, $d->strike('Splash Cymbal','Bass Drum 1'));
   }
 
+  # Multi-tracking:
+  use MIDI::Simple::Drummer;
+  my $d = MIDI::Simple::Drummer->new(-file => "$0.mid");
+  $d->patterns(b1 => \&hihat);
+  $d->patterns(b2 => \&backbeat);
+  $d->sync_tracks(
+    sub { $d->beat(-name => 'b1') },
+    sub { $d->beat(-name => 'b2') },
+  );
+  $d->write();
+  sub hihat { # tick
+    my $self = shift;
+    $self->note($self->EIGHTH, $self->tick) for 1 .. 2 * $self->beats;
+  }
+  sub backbeat { # kick/snare
+    my $self = shift;
+    $self->note($self->QUARTER, $self->rotate($_)) for 1 .. $self->beats;
+  }
+
 =head1 DESCRIPTION
 
-This is a "robotic" drummer that 1) hides L<MIDI::Simple> details and
-2) provides simple methods to construct beats.
+This is a "robotic" drummer that provides simple methods to make
+beats.
 
-This is not a "drum machine", that you control in any traditional
-sense.  It is intended to be a "sufficiently intelligent" drummer,
-with which you can practice, improvise, compose, record and
-experiment.
+This is not a "drum machine" that you control in a traditional,
+mechanical sense.  It is intended to be a "sufficiently intelligent"
+drummer, with which you can practice, improvise, compose, record
+and experiment.
 
-These "beats" are entirely perl and any available method can be
-used to generate the phrases - Stochastic, Evolutionary, L-system,
-Recursive descent grammar, whatever.
+These "beats" are entirely constructed with perl and as such, any
+method can be used to generate the phrases - Stochastic, Evolutionary,
+L-system, Recursive descent grammar, Bayseian, Markov,
+Quantumm::Whatever...
 
 Note that B<you>, the programmer, should know what the patterns and
 kit elements are named and what they do.  For these, check out the
@@ -382,7 +509,7 @@ files and the F<.mid> files they produce.
 
 The default kit is the B<exciting>, general MIDI drumkit.  Fortunately,
 you can import the F<.mid> file into your favorite sequencer and
-assign better patches.  I<Voila!>
+assign better patches.  I<Voilà!>
 
 =head1 METHODS
 
@@ -395,16 +522,19 @@ Return a new C<MIDI::Simple::Drummer> instance with these arguments:
   # MIDI
   -channel => 9
   -volume  => 100
-  # Rhythm
+  -pan     => 64
+  # Rhythm metrics
   -accent  => 30
   -bpm     => 120
   -phrases => 4
+  -bars    => 4
   -beats   => 4
+  -swing   => 0,
   # The Goods[TM].
   -file     => Drummer.mid
-  -kit      => Set by the API if not provided
-  -patterns => Set by the API if not provided
-  -score    => MIDI::Simple->new_score (Set by API...)
+  -kit      => Set by the API unless provided
+  -patterns => Set by the API "
+  -score    => "
 
 These arguments can be overridden with this constuctor or the
 following accessor methods.
@@ -412,21 +542,31 @@ following accessor methods.
 =head2 volume()
 
   $x = $d->volume;
-  $x = $d->volume($y);
+  $d->volume($x);
 
 Return and set the volume.
 
+=head2 pan()
+
+  $x = $d->pan;
+  $d->pani($x);
+
+Return or set the pan (C<CC#10>) from 1 left to 127 right.
+
 =head2 bpm()
 
 Beats per minute.
 
-=head2 phrases()
+=head2 phrases(), bars(), beats()
 
-Number of phrases to play.
+Number of phrases, measures and beats per measure.  These are just
+variables for you to use as rhythm metrics.  They have no other
+meaning or hidden functionality.
 
-=head2 beats()
+=head2 swing()
 
-Number of beats per measure.
+Use triplet or even time.  This just sets an attribute that can be
+checked conditionally.
 
 =head2 channel()
 
@@ -436,6 +576,11 @@ MIDI channel.
 
 Name for the F<.mid> file to write.
 
+=head2 sync_tracks()
+
+Combine beats in parallel with an argument list of anonymous
+subroutines.
+
 =head2 patterns()
 
 Return or set known style patterns.
@@ -443,18 +588,25 @@ Return or set known style patterns.
 =head2 score()
 
   $x = $d->score;
-  $x = $d->score($y);
-  $x = $d->score($y, 'V127');
-  $x = $d->score($volume);
+  $x = $d->score($score);
+  $x = $d->score($score, 'V127');
+  $x = $d->score('V127');
 
-Return or set the L<MIDI::Simple/score> object if provided first.  If
-there are any other arguments, they are set as score no-ops.
+Return or set the L<MIDI::Simple/score> if provided as the first
+argument.  If there are any other arguments, they are set as score
+no-ops.
 
 =head2 accent()
 
+  $x = $d->accent();
+
 Either return the current volume plus the accent increment or set the
 accent increment.  This has an upper limit of MIDI fff.
 
+=head2 duck()
+
+Reduce the volume by the accent volume.
+
 =head2 strike()
 
   $x = $d->strike;
@@ -491,13 +643,6 @@ L<MIDI::Simple/n>.
 Add a rest to the score.  This is a pass-through to
 L<MIDI::Simple/r>.
 
-=head2 no_op()
-
-  $d->no_op('V127');
-
-Add a no-op to the score.  This is a pass-through to
-L<MIDI::Simple/noop>.
-
 =head2 metronome()
 
   $d->metronome;
@@ -677,28 +822,37 @@ predefined C<kick> and C<snare> patches.
 These are meant to avoid literal strings and the need to remember
 and type the relevant MIDI variables.
 
-=head2 WHOLE
+=head2 WHOLE or 1st
 
   $x = $d->WHOLE;
+  $x = $d->_1st;
 
 Return C<'wn'>.
 
-=head2 HALF
+=head2 HALF or or _2nd
 
 Return C<'hn'>.
 
-=head2 QUARTER
+=head2 QUARTER or _4th
 
 Return C<'qn'>.
 
-=head2 EIGHTH
+=head2 EIGHTH or _8th
 
 Return C<'en'>.
 
-=head2 SIXTEENTH
+=head2 SIXTEENTH or _16th
 
 Return C<'sn'>.
 
+=head2 THIRTYSECOND or _32nd
+
+Return C<'yn'>.
+
+=head2 SIXTYFOURTH or _64th
+
+Return C<'xn'>.
+
 =head2 _p2n()
 
 Return C<%MIDI::percussion2notenum> a la L<MIDI/GOODIES>.
@@ -710,25 +864,22 @@ Return the inverse: C<%MIDI::notenum2percussion>.
 =head2 _default_patterns()
 
 Patterns provided by default. This is C<{}>, that is, nothing.
+This is defined in a I<MIDI::Simple::Drummer::*> style package.
 
 =head2 _default_kit()
 
-Kit provided by default. This is a subset of the general MIDI kit.
+Kit provided by default. This is a subset of the B<exciting> general
+MIDI kit.  This can also be defined in a I<MIDI::Simple::Drummer::*>
+style package, to use better patches.
 
 =head1 TO DO
 
-* It don't mean a thing if it ain't got that swing. (That is, make a
-<MIDI::Simple::Drummer::Jazz> package.)
+* Comprehend time signature via beat construction and keep a running
+clock/total to know where we are in time, at all times.
 
-* Add 32nd and 64th durations to C<%MIDI::Simple::Length>.
+* Intelligently modulate dynamics to add nuance and "humanize."
 
-* Comprehend time signature via beat construction and keep a "running
-clock/total" to know where we are in time, at all times.
-
-* Intelligently modulate dynamics - "add nuance" like accent and
-crescendo, etc.
-
-* Praise Les Paul and Multi-track ASAP.
+* Make a C<MIDI::Simple::Drummer::AC\x{26A1}DC> ?
 
 * Import patterns via L<MIDI::Simple/read_score>?
 
@@ -736,25 +887,28 @@ crescendo, etc.
 
 =head1 SEE ALSO
 
-The F<eg/*> and F<t/*> files, that come with this distribution.
+The F<eg/*> and F<t/*> files, that come with this distribution show
+how to use it.
 
-L<MIDI::Simple::Drummer::API>
+The I<MIDI::Simple::Drummer::*> styles, which you can make (and upload).
 
-The I<MIDI::Simple::Drummer::*> style package(s).
-
-L<MIDI::Simple> itself.
+L<MIDI::Simple> itself, of course.
 
 L<http://maps.google.com/maps?q=mike+avery+joplin> - my drum teacher.
 
+This distribution at
+L<https://github.com/ology/Music/tree/master/MIDI-Simple-Drummer>,
+where interim changes are made, long before any CPAN release.
+
 =head1 AUTHOR AND COPYRIGHT
 
 Gene Boggs E<lt>gene@cpan.orgE<gt>
 
-Copyright 2010, Gene Boggs, All Rights Reserved.
+Copyright 2012, Gene Boggs, All Rights Reserved.
 
 =head1 LICENSE
 
-This program is free software; you can redistribute or modify it under
-the same terms as Perl itself.
+This program is free software; you can redistribute or modify it
+under the same terms as Perl itself.
 
 =cut
